/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Input Tag Properties Dialog.
 *
 * The Initial Developer of the Original Code is
 * Neil Rashbrook.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Neil Rashbrook <neil@parkwaycc.co.uk>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var dialog;
var insertNew;
var inputElement;

// dialog initialization code

function Startup()
{
  if (!InitEditorShell())
    return;

  doSetOKCancel(onOK, onCancel);

  dialog = {
    inputType:        document.getElementById( "InputType" ),
    inputNameDeck:    document.getElementById( "InputNameDeck" ),
    inputName:        document.getElementById( "InputName" ),
    inputValueDeck:   document.getElementById( "InputValueDeck" ),
    inputValue:       document.getElementById( "InputValue" ),
    inputDeck:        document.getElementById( "InputDeck" ),
    inputChecked:     document.getElementById( "InputChecked" ),
    inputSelected:    document.getElementById( "InputSelected" ),
    inputReadOnly:    document.getElementById( "InputReadOnly" ),
    inputDisabled:    document.getElementById( "InputDisabled" ),
    inputTabIndex:    document.getElementById( "InputTabIndex" ),
    inputAccessKey:   document.getElementById( "InputAccessKey" ),
    inputSize:        document.getElementById( "InputSize" ),
    inputMaxLength:   document.getElementById( "InputMaxLength" ),
    inputAccept:      document.getElementById( "InputAccept" ),
    MoreSection:      document.getElementById( "MoreSection" ),
    MoreFewerButton:  document.getElementById( "MoreFewerButton" ),
    AdvancedEditDeck: document.getElementById( "AdvancedEditDeck" )
  };

  // Get a single selected input element
  var tagName = "input";
  inputElement = editorShell.GetSelectedElement(tagName);

  if (inputElement)
  {
    // We found an element and don't need to insert one
    insertNew = false;
  }
  else
  {
    insertNew = true;

    // We don't have an element selected,
    //  so create one with default attributes

    inputElement = editorShell.CreateElementWithDefaults(tagName);
    if( !inputElement )
    {
      dump("Failed to get selected element or create a new one!\n");
      window.close();
      return;
    }

    var imageElement = editorShell.GetSelectedElement("img");
    if (imageElement)
    {
      // We found an image element, convert it to an input type="image"
      inputElement.setAttribute("type", "image");

      var attributes = ["src", "alt", "width", "height", "hspace", "vspace", "border", "align"];
      for (i in attributes)
        inputElement.setAttribute(attributes[i], imageElement.getAttribute(attributes[i]));
    }
    else
    {
      inputElement.setAttribute("value", GetSelectionAsText());
    }
  }

  // Make a copy to use for AdvancedEdit
  globalElement = inputElement.cloneNode(false);

  InitDialog();

  InitMoreFewer();

  dialog.inputType.focus();

  SetWindowLocation();
}

function InitDialog()
{
  var type = globalElement.getAttribute("type");
  var index = 0;
  switch (type)
  {
    case "button":
      index = 9;
      break;
    case "checkbox":
      index = 2;
      break;
    case "file":
      index = 6;
      break;
    case "hidden":
      index = 7;
      break;
    case "image":
      index = 8;
      break;
    case "password":
      index = 1;
      break;
    case "radio":
      index = 3;
      break;
    case "reset":
      index = 5;
      break;
    case "submit":
      index = 4;
      break;
  }
  dialog.inputType.selectedIndex = index;
  dialog.inputName.value = globalElement.getAttribute("name");
  dialog.inputValue.value = globalElement.getAttribute("value");
  dialog.inputChecked.setAttribute("checked", globalElement.hasAttribute("checked"));
  dialog.inputSelected.setAttribute("checked", globalElement.hasAttribute("checked"));
  dialog.inputReadOnly.setAttribute("checked", globalElement.hasAttribute("readonly"));
  dialog.inputDisabled.setAttribute("checked", globalElement.hasAttribute("disabled"));
  dialog.inputTabIndex.value = globalElement.getAttribute("tabindex");
  dialog.inputAccessKey.value = globalElement.getAttribute("accesskey");
  dialog.inputSize.value = globalElement.getAttribute("size");
  dialog.inputMaxLength.value = globalElement.getAttribute("maxlength");
  dialog.inputAccept.value = globalElement.getAttribute("accept");
  SelectInputType();
}

function SelectInputType()
{
  var index = dialog.inputType.selectedIndex;
  dialog.AdvancedEditDeck.setAttribute("index", 0);
  dialog.inputValueDeck.setAttribute("index", 0);
  dialog.inputValue.disabled = false;
  dialog.inputChecked.disabled = index != 2;
  dialog.inputSelected.disabled = index != 3;
  dialog.inputReadOnly.disabled = index > 1;
  dialog.inputTabIndex.disabled = index == 7;
  dialog.inputAccessKey.disabled = true;
  dialog.inputSize.disabled = index > 1;
  dialog.inputMaxLength.disabled = index > 1;
  dialog.inputAccept.disabled = index != 6;
  switch (index)
  {
    case 0:
    case 1:
      dialog.inputValueDeck.setAttribute("index", 1);
      dialog.inputDeck.setAttribute("index", 2);
      break;
    case 2:
      dialog.inputDeck.setAttribute("index", 0);
      break;
    case 3:
      dialog.inputDeck.setAttribute("index", 1);
      dialog.inputNameDeck.setAttribute("index", 1);
      return;
    case 4:
    case 5:
    case 9:
      dialog.inputAccessKey.disabled = false;
      break;
    case 6:
      dialog.inputValue.disabled = true;
      dialog.inputAccept.disabled = false;
      break;
    case 8:
      dialog.inputValue.disabled = true;
      dialog.AdvancedEditDeck.setAttribute("index", 1);
      break;
    case 7:
      dialog.inputValueDeck.setAttribute("index", 1);
      break;
  }
  dialog.inputNameDeck.setAttribute("index", 0);
}

function doImageProperties()
{
  window.openDialog("chrome://editor/content/EdImageProps.xul",
                    "_blank", "chrome,close,titlebar,modal", globalElement);
  window.focus();
}

function ValidateData()
{
  var index = dialog.inputType.selectedIndex;
  switch (index) {
    case 4:
    case 5:
      break;
    case 8:
      if (!globalElement.hasAttribute("src")) {
        doImageProperties();
        if (!globalElement.hasAttribute("src"))
          return false;
      }
      break;
    case 3:
      if (!dialog.inputName.value || !dialog.inputValue.value) {
        AlertWithTitle(GetString("Alert"), GetString("InputValueError"));
        if (!dialog.inputName.value)
          dialog.inputName.focus();
        else
          dialog.inputValue.focus();
        return false;
      }
    default:
      if (!dialog.inputName.value) {
        AlertWithTitle(GetString("Alert"), GetString("InputNameError"));
        dialog.inputName.focus();
        return false;
      }
  }
  var attributes = {
    type: "",
    name: dialog.inputName.value,
    value: dialog.inputValue.value,
    tabindex: dialog.inputTabIndex.value,
    accesskey: "",
    size: "",
    maxlength: "",
    accept: ""
  };
  var flags = {
    checked: false,
    readonly: false,
    disabled: dialog.inputDisabled.checked
  };
  switch (index)
  {
    case 1:
      attributes.type = "password";
    case 0:
      flags.readonly = dialog.inputReadOnly.checked;
      attributes.size = dialog.inputSize.value;
      attributes.maxlength = dialog.inputMaxLength.value;
      break;
    case 2:
      attributes.type = "checkbox";
      flags.checked = dialog.inputChecked.checked;
      break;
    case 3:
      attributes.type = "radio";
      flags.checked = dialog.inputSelected.checked;
      break;
    case 4:
      attributes.type = "submit";
      attributes.accesskey = dialog.inputAccessKey.value;
      break;
    case 5:
      attributes.type = "reset";
      attributes.accesskey = dialog.inputAccessKey.value;
      break;
    case 6:
      attributes.type = "file";
      attributes.accept = dialog.inputAccept.value;
      attributes.value = "";
      break;
    case 7:
      attributes.type = "hidden";
      attributes.tabindex = "";
      break;
    case 8:
      attributes.type = "image";
      attributes.value = "";
      break;
    case 9:
      attributes.type = "button";
      attributes.accesskey = dialog.inputAccessKey.value;
      break;
  }
  for (var a in attributes) {
    if (attributes[a])
      globalElement.setAttribute(a, attributes[a]);
    else
      globalElement.removeAttribute(a);
  }
  for (var f in flags) {
    if (flags[f])
      globalElement.setAttribute(f, "");
    else
      globalElement.removeAttribute(f);
  }
  return true;
}

function onOK()
{
  if (ValidateData()) {
    // All values are valid - copy to actual element in doc or
    //   element created to insert

    editorShell.CloneAttributes(inputElement, globalElement);

    if (insertNew)
    {
      try {
        // 'true' means delete the selection before inserting
        // in case were are converting an image to an input type="image"
        editorShell.InsertElementAtSelection(inputElement, true);
      } catch (e) {
        dump(e);
      }
    }

    SaveWindowLocation();

    return true;
  }
  return false;
}

